@@ -13,9 +13,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Shaun McCance  <shaunm@gnome.org>
  */
@@ -301,8 +299,9 @@ resolve_start (YelpUri *uri)
 
     if (priv->resolver == NULL) {
         g_object_ref (uri);
-        priv->resolver = g_thread_create ((GThreadFunc) resolve_async,
-                                          uri, FALSE, NULL);
+        priv->resolver = g_thread_new ("uri-resolve",
+                                       (GThreadFunc) resolve_async,
+                                       uri);
     }
 }
 
